@@ -51,7 +51,7 @@ private Q_SLOTS:
         QImage img(QStringLiteral(SOURCE_DIR "/barcodes/") + fileName);
         QVERIFY(!img.isNull());
 
-#ifdef HAVE_ZXING
+#ifdef HAVE_ZXING_ANY
         QCOMPARE(BarcodeDecoder::decodePdf417(img), QStringLiteral("PDF417 is a stacked linear barcode symbol format used in a variety of applications, primarily transport, identification cards, and inventory management."));
 #endif
     }
@@ -60,18 +60,41 @@ private Q_SLOTS:
     {
         QImage img(QStringLiteral(SOURCE_DIR "/barcodes/aztec.png"));
         QVERIFY(!img.isNull());
-#ifdef HAVE_ZXING
+#ifdef HAVE_ZXING_ANY
         QCOMPARE(BarcodeDecoder::decodeAztec(img), QStringLiteral("This is an example Aztec symbol for Wikipedia."));
 #endif
 
         img.load(QStringLiteral(SOURCE_DIR "/barcodes/uic918-3star.png"));
         QVERIFY(!img.isNull());
-#ifdef HAVE_ZXING
+#ifdef HAVE_ZXING_ANY
         const auto b = BarcodeDecoder::decodeAztecBinary(img);
         QCOMPARE(b.size(), 351);
         QVERIFY(b.startsWith("OTI010080000020"));
 #endif
     }
+
+    void testQRCode_data()
+    {
+            QTest::addColumn<QString>("fileName");
+            QTest::addColumn<QString>("result");
+
+            QTest::newRow("1") << QStringLiteral("qrcode1.png") << QStringLiteral("M$K0YGV0G");
+            QTest::newRow("2") << QStringLiteral("qrcode2.png") << QStringLiteral("KZEXO4HRE");
+    }
+
+    void testQRCode()
+    {
+        QFETCH(QString, fileName);
+        QFETCH(QString, result);
+
+        QImage img(QStringLiteral(SOURCE_DIR "/barcodes/") + fileName);
+        QVERIFY(!img.isNull());
+
+#ifdef HAVE_ZXING_ANY
+        QCOMPARE(BarcodeDecoder::decodeQRCode(img), result);
+#endif
+
+    }
 };
 
 QTEST_APPLESS_MAIN(BarcodeDecoderTest)
