@@ -22,35 +22,22 @@
 
 #include "kitinerary_export.h"
 
-#include <memory>
-
 class QJsonArray;
-class QString;
 
 namespace KItinerary {
 
-class StructuredDataExtractorPrivate;
+class HtmlDocument;
 
 /** Extract schema.org structured data from HTML text.
  *  @see https://developers.google.com/gmail/markup/getting-started
  */
-class KITINERARY_EXPORT StructuredDataExtractor
+namespace StructuredDataExtractor
 {
-public:
-    StructuredDataExtractor();
-    StructuredDataExtractor(const StructuredDataExtractor&) = delete;
-    StructuredDataExtractor(StructuredDataExtractor&&);
-    ~StructuredDataExtractor();
-
-    /** Attempt to find JSON-LD data in the given HTML content. */
-    void parse(const QString &text);
-
-    /** Returns the extracted data. */
-    QJsonArray data() const;
-
-private:
-    std::unique_ptr<StructuredDataExtractorPrivate> d;
-};
+    /** Traverse the given HTML document and search for any embedded JSON-LD or Microdata.
+     *  @internal only exported for unit tests
+     */
+    KITINERARY_EXPORT QJsonArray extract(HtmlDocument *doc);
+}
 
 }
 
